;+
;PROCEDURE:	mvn_sta_pfdpu_hv_turnon_plot,pathname=pathname,all=all,apids=apids
;PURPOSE:	
;	Loads and Plots STATIC data for HV turnon
;INPUT:		
;
;KEYWORDS:
;	pathname	string		if not set, then pathname = 'maven/dpu/prelaunch/live/flight/Split_At_20130524_224251/initial/common_block.dat'
;	all		0/1		if set, then all the temporary tplot structures generated by the decommutator are kept
;	apids		strarr		if set, selectes subset of apids to generate tplot structures
;
;
;CREATED BY:	J. McFadden
;VERSION:	1
;LAST MODIFICATION:  2013/06/11
;MOD HISTORY:
;
;NOTES:	  
;	
;-
pro mvn_sta_pfdpu_hv_turnon_plot,pathname=pathname,all=all,apids=apids

;initialize for plotting

	cols=get_colors()

if not keyword_set(pathname) then begin
	if keyword_set(l0) then begin
		pathname = 'c:/data/maven/l0/mvn_pfp_svy_l0_20150803_v1.dat'					;  ATLO l0 file
	endif else begin
		pathname = 'maven/dpu/prelaunch/live/flight/Split_At_20130524_224251/initial/common_block.dat'			;  ATLO Self-Test - replay			
	endelse
endif

; old code
;if keyword_set(l0) then begin
;	mvn_sta_l0_load,pathname=pathname
;endif else begin
;	mvn_sta_cblk_load,pathname=pathname
;endelse

	starttime = systime(1)
	mvn_pfp_l0_file_read,pathname=pathname,file=file,/static	
	dprint,'Done in ',systime(1)-starttime,' seconds'


;****************************************************************************************************************
; calibrate housekeeping

	mvn_sta_hkp_cal,def_lim=1

;****************************************************************************************************************
; calibrate data, use keywords hkp=1,raw=1 to get rid of raw hkp and raw data tplot structures

	mvn_sta_prod_cal,all=all,apids=apids

;****************************************************************************************************************
; Misc limits -- for diagnostic on hkp

	options,'mvn_STA_2A_SEQ_CNTR',ytitle='sta!Chkp Avg!CSEQ_CNTR'
	options,'mvn_STA_2A_SEQ_DCNTR',ytitle='sta!Chkp Avg!CSEQ_DCNTR'
	options,'mvn_STA_2A_SEQ_CNTR',psym=1
	options,'mvn_STA_2A_SEQ_DCNTR',psym=1

	ylim,'mvn_sta_2A_hkp_ch0_Temp_Dig',-40,60,0
	ylim,'mvn_sta_2A_hkp_ch15_Temp_FPGA',-40,60,0
	ylim,'mvn_sta_2A_hkp_ch22_Temp_LVPS',-40,60,0

;****************************************************************************************************************
; Lv Plots -- for LV turnon

	window,2

	tplot,['mvn_sta_2A_hkp_ch0_Temp_Dig','mvn_sta_2A_hkp_ch1_Imon_ADC5V','mvn_sta_2A_hkp_ch2_+5V_D'$
		,'mvn_sta_2A_hkp_ch3_+3.3V_D','mvn_sta_2A_hkp_ch4_+5V_A','mvn_sta_2A_hkp_ch5_-5V_A'$
		,'mvn_sta_2A_hkp_ch6_+12V_A','mvn_sta_2A_hkp_ch7_+28V'$
		],title='LV '+pathname,window=-1

;****************************************************************************************************************

; HV ramp turnon

	window,3
	ylim,'mvn_sta_DA_R3_T',.5,1.e4,1
	ylim,'mvn_sta_C0_P1A_tot',.1,1.e6,1


	tplot,['mvn_sta_2A_hkp_ch8_Vmon_Swp','mvn_sta_2A_hkp_ch16_Imon_15kV','mvn_sta_2A_hkp_ch17_Vmon_15kV'$
		,'mvn_sta_2A_hkp_ch18_Imon_MCP','mvn_sta_2A_hkp_ch19_Vmon_MCP','mvn_sta_2A_hkp_ch20_Imon_Raw'$
		,'mvn_sta_2A_hkp_ch21_Vmon_Def_Raw','mvn_sta_DA_R3_T','mvn_sta_C0_P1A_tot'$
		],title='HV '+pathname,window=-1


;****************************************************************************************************************
; HV turnon for vacuum 

	options,'mvn_sta_C0_P1A_tot',psym=-1
	options,'mvn_sta_D8_R1_Time_RST',psym=-1
	options,'mvn_STA_*_SEQ_CNTR',psym=1

	ylim,'mvn_sta_2A_hkp_ch7_+28V',25,33,0

	ylim,'mvn_sta_D8_R1_Time_RST',0,0,1
	ylim,'mvn_sta_DB_MH_M64',-3,65,0
	ylim,'mvn_sta_DA_R3_T',.1,1.e4,1
	options,'mvn_sta_DA_R3_T',psym=1
	options,'mvn_sta_C0_P1A_tot',psym=1
	options,'mvn_sta_DB_MH_M64',panel_size=2

	options,'mvn_sta_DA_R3_T',panel_size=2
	ylim,'mvn_STA_C0_att_s',-1,4,0
	ylim,'mvn_STA_C0_att_e',-1,4,0
	ylim,'mvn_STA_C0_att_w',-1,8,0



; Final ACC turnon after MCP is on

	window,0

	tplot,['mvn_sta_C0_P1A_tot','mvn_sta_C0_P1A_E','mvn_sta_C4_P1C_M','mvn_sta_CA_P3_A','mvn_sta_C8_P2_D'$
		,'mvn_sta_D8_R1_Time_RST'$
		,'mvn_sta_DB_MH_M64'$
		],title=pathname,window=-1

;	tlimit,/full

;	tlimit


;****************************************************************************************************************
;****************************************************************************************************************

end